# PYTHON SCRIPT TO PLOT THE FATIGUE DISTRIBUTION. COMPOSITE PANELS OF MULTIPLE FIGURES FOUND IN MANUSCRIPT HAVE BEEN CREATED EXTERNALLY.
# BY Lars Einar S. Stieng, 14.05.2018

# IMPORT PACKAGES.

import numpy as np
import matplotlib.pyplot as plt

# LOAD DATA.

data = np.loadtxt('results_for_plotting/tb_fatigue_8points_base_model.txt')

# NORMALIZE BY SUM OF DATA TO MAKE INTO PROBABILITY DISTRIBUTION.

y = data/np.sum(data)

# NORMALIZE BY MAXIMUM FOR CLARITY.

y = y/np.max(y)

# CREATE VECTOR REPRESENTING THE LOAD CASES.

x = np.linspace(1,np.size(y),np.size(y))

# CREATE VECTOR REPRESENTING THE LOAD CASES SORTED BY SEVERITY.

inds = np.argsort(y)

# EXTRACT THE 25 MOST SEVERE LOAD CASES.

mask = np.ones(3647,dtype=bool)

mask[inds[-25:]] = False

x1 = x[mask]

x2 = x[inds[-25:]]

yless = y[mask]
yrest = y[inds[-25:]]

# PLOT THE DISTRIBUTION EXCEPT THE 25 MOST SEVERE POINTS. THEN PLOT ONLY THESE POINTS WITH NEW SYMBOL AND COLOR AND WITH LARGER MARKER SIZE. USE LOG SCALE.

plt.scatter(x1,yless,color='#1f78b4',marker='.',s=30)
plt.scatter(x2,yrest,color='#33a02c',marker='x',s=60)
ax = plt.gca()
ax.set_yscale('log')

# SET AXES AND TICKS. NO TICKS ON X-AXIS. SET X- AND Y-LABELS.

plt.xlim([0,np.size(y)+5])

plt.ylim([10**(-10),10**(0.2)])

plt.yticks([10**(-8),10**(-6),10**(-4),10**(-2),10**0],[r"$10^{-8}$",r"$10^{-6}$",r"$10^{-4}$",r"$10^{-2}$",r"$10^{0}$"],size=20)

plt.minorticks_on()
plt.tick_params(width=2.5,length=5)
plt.tick_params(which='minor',width=1,length=5)

ax.yaxis.set_ticks_position('left')

plt.tick_params(
    axis='x',          
    which='both',      
    bottom=False,      
    top=False,
	labelbottom=False)
    

plt.ylabel('Normalized fatigue damage',size=20)
plt.xlabel('Load cases',size=25)

# MAKE EXTRA SPACE AROUND AXIS LABELS.

t = ax.yaxis.get_offset_text()
t.set_size(20)

plt.gcf().subplots_adjust(left=0.20)

# SHOW PLOT OR SAVE AS PDF.

#plt.show()

plt.savefig('fatigue_damage_dist_with_mask.pdf',format='pdf')
